pub struct Word {
pub word: String,
pub start: f32,
pub end: f32,
pub probability: f32,
}Available on crate feature
whisper only.Expand description
Represents a transcribed word with detailed timing and probability.
Fields
word: StringThe transcribed word text.
start: f32Start time in seconds relative to the audio start.
end: f32End time in seconds relative to the audio start.
probability: f32Confidence probability score bounded between 0.0 and 1.0.